Class: Aws::CloudSearch::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudSearch::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloudsearch/client.rb,
sig/client.rbs
Overview
An API client for CloudSearch. To construct a client, you need to configure a :region and :credentials.
client = Aws::CloudSearch::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BuildSuggestersResponseSuccess, _CreateDomainResponseSuccess, _DefineAnalysisSchemeResponseSuccess, _DefineExpressionResponseSuccess, _DefineIndexFieldResponseSuccess, _DefineSuggesterResponseSuccess, _DeleteAnalysisSchemeResponseSuccess, _DeleteDomainResponseSuccess, _DeleteExpressionResponseSuccess, _DeleteIndexFieldResponseSuccess, _DeleteSuggesterResponseSuccess, _DescribeAnalysisSchemesResponseSuccess, _DescribeAvailabilityOptionsResponseSuccess, _DescribeDomainEndpointOptionsResponseSuccess, _DescribeDomainsResponseSuccess, _DescribeExpressionsResponseSuccess, _DescribeIndexFieldsResponseSuccess, _DescribeScalingParametersResponseSuccess, _DescribeServiceAccessPoliciesResponseSuccess, _DescribeSuggestersResponseSuccess, _IndexDocumentsResponseSuccess, _ListDomainNamesResponseSuccess, _UpdateAvailabilityOptionsResponseSuccess, _UpdateDomainEndpointOptionsResponseSuccess, _UpdateScalingParametersResponseSuccess, _UpdateServiceAccessPoliciesResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#build_suggesters(params = {}) ⇒ Types::BuildSuggestersResponse
Indexes the search suggestions.
-
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a new search domain.
-
#define_analysis_scheme(params = {}) ⇒ Types::DefineAnalysisSchemeResponse
Configures an analysis scheme that can be applied to a
textortext-arrayfield to define language-specific text processing options. -
#define_expression(params = {}) ⇒ Types::DefineExpressionResponse
Configures an
Expressionfor the search domain. -
#define_index_field(params = {}) ⇒ Types::DefineIndexFieldResponse
Configures an
IndexFieldfor the search domain. -
#define_suggester(params = {}) ⇒ Types::DefineSuggesterResponse
Configures a suggester for a domain.
-
#delete_analysis_scheme(params = {}) ⇒ Types::DeleteAnalysisSchemeResponse
Deletes an analysis scheme.
-
#delete_domain(params = {}) ⇒ Types::DeleteDomainResponse
Permanently deletes a search domain and all of its data.
-
#delete_expression(params = {}) ⇒ Types::DeleteExpressionResponse
Removes an
Expressionfrom the search domain. -
#delete_index_field(params = {}) ⇒ Types::DeleteIndexFieldResponse
Removes an
IndexFieldfrom the search domain. -
#delete_suggester(params = {}) ⇒ Types::DeleteSuggesterResponse
Deletes a suggester.
-
#describe_analysis_schemes(params = {}) ⇒ Types::DescribeAnalysisSchemesResponse
Gets the analysis schemes configured for a domain.
-
#describe_availability_options(params = {}) ⇒ Types::DescribeAvailabilityOptionsResponse
Gets the availability options configured for a domain.
-
#describe_domain_endpoint_options(params = {}) ⇒ Types::DescribeDomainEndpointOptionsResponse
Returns the domain's endpoint options, specifically whether all requests to the domain must arrive over HTTPS.
-
#describe_domains(params = {}) ⇒ Types::DescribeDomainsResponse
Gets information about the search domains owned by this account.
-
#describe_expressions(params = {}) ⇒ Types::DescribeExpressionsResponse
Gets the expressions configured for the search domain.
-
#describe_index_fields(params = {}) ⇒ Types::DescribeIndexFieldsResponse
Gets information about the index fields configured for the search domain.
-
#describe_scaling_parameters(params = {}) ⇒ Types::DescribeScalingParametersResponse
Gets the scaling parameters configured for a domain.
-
#describe_service_access_policies(params = {}) ⇒ Types::DescribeServiceAccessPoliciesResponse
Gets information about the access policies that control access to the domain's document and search endpoints.
-
#describe_suggesters(params = {}) ⇒ Types::DescribeSuggestersResponse
Gets the suggesters configured for a domain.
-
#index_documents(params = {}) ⇒ Types::IndexDocumentsResponse
Tells the search domain to start indexing its documents using the latest indexing options.
-
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Lists all search domains owned by an account.
-
#update_availability_options(params = {}) ⇒ Types::UpdateAvailabilityOptionsResponse
Configures the availability options for a domain.
-
#update_domain_endpoint_options(params = {}) ⇒ Types::UpdateDomainEndpointOptionsResponse
Updates the domain's endpoint options, specifically whether all requests to the domain must arrive over HTTPS.
-
#update_scaling_parameters(params = {}) ⇒ Types::UpdateScalingParametersResponse
Configures scaling parameters for a domain.
-
#update_service_access_policies(params = {}) ⇒ Types::UpdateServiceAccessPoliciesResponse
Configures the access rules that control access to the domain's document and search endpoints.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2013 2014 2015 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 2013 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2016 2017 2018 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 2016 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1986 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CloudSearch') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cloudsearch' context[:gem_version] = '1.91.0' Seahorse::Client::Request.new(handlers, context) end |
#build_suggesters(params = {}) ⇒ Types::BuildSuggestersResponse
Indexes the search suggestions. For more information, see Configuring Suggesters in the Amazon CloudSearch Developer Guide.
86 |
# File 'sig/client.rbs', line 86
def build_suggesters: (
|
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a new search domain. For more information, see Creating a Search Domain in the Amazon CloudSearch Developer Guide.
96 |
# File 'sig/client.rbs', line 96
def create_domain: (
|
#define_analysis_scheme(params = {}) ⇒ Types::DefineAnalysisSchemeResponse
Configures an analysis scheme that can be applied to a text or
text-array field to define language-specific text processing
options. For more information, see Configuring Analysis Schemes
in the Amazon CloudSearch Developer Guide.
106 |
# File 'sig/client.rbs', line 106
def define_analysis_scheme: (
|
#define_expression(params = {}) ⇒ Types::DefineExpressionResponse
Configures an Expression for the search domain. Used to create new
expressions and modify existing ones. If the expression exists, the
new configuration replaces the old one. For more information, see
Configuring Expressions in the Amazon CloudSearch Developer
Guide.
127 |
# File 'sig/client.rbs', line 127
def define_expression: (
|
#define_index_field(params = {}) ⇒ Types::DefineIndexFieldResponse
Configures an IndexField for the search domain. Used to create new
fields and modify existing ones. You must specify the name of the
domain you are configuring and an index field configuration. The index
field configuration specifies a unique name, the index field type, and
the options you want to configure for the field. The options you can
specify depend on the IndexFieldType. If the field exists, the new
configuration replaces the old one. For more information, see
Configuring Index Fields in the Amazon CloudSearch Developer
Guide.
141 |
# File 'sig/client.rbs', line 141
def define_index_field: (
|
#define_suggester(params = {}) ⇒ Types::DefineSuggesterResponse
Configures a suggester for a domain. A suggester enables you to display possible matches before users finish typing their queries. When you configure a suggester, you must specify the name of the text field you want to search for possible matches and a unique name for the suggester. For more information, see Getting Search Suggestions in the Amazon CloudSearch Developer Guide.
238 |
# File 'sig/client.rbs', line 238
def define_suggester: (
|
#delete_analysis_scheme(params = {}) ⇒ Types::DeleteAnalysisSchemeResponse
Deletes an analysis scheme. For more information, see Configuring Analysis Schemes in the Amazon CloudSearch Developer Guide.
256 |
# File 'sig/client.rbs', line 256
def delete_analysis_scheme: (
|
#delete_domain(params = {}) ⇒ Types::DeleteDomainResponse
Permanently deletes a search domain and all of its data. Once a domain has been deleted, it cannot be recovered. For more information, see Deleting a Search Domain in the Amazon CloudSearch Developer Guide.
267 |
# File 'sig/client.rbs', line 267
def delete_domain: (
|
#delete_expression(params = {}) ⇒ Types::DeleteExpressionResponse
Removes an Expression from the search domain. For more information,
see Configuring Expressions in the Amazon CloudSearch Developer
Guide.
277 |
# File 'sig/client.rbs', line 277
def delete_expression: (
|
#delete_index_field(params = {}) ⇒ Types::DeleteIndexFieldResponse
Removes an IndexField from the search domain. For more information,
see Configuring Index Fields in the Amazon CloudSearch Developer
Guide.
288 |
# File 'sig/client.rbs', line 288
def delete_index_field: (
|
#delete_suggester(params = {}) ⇒ Types::DeleteSuggesterResponse
Deletes a suggester. For more information, see Getting Search Suggestions in the Amazon CloudSearch Developer Guide.
299 |
# File 'sig/client.rbs', line 299
def delete_suggester: (
|
#describe_analysis_schemes(params = {}) ⇒ Types::DescribeAnalysisSchemesResponse
Gets the analysis schemes configured for a domain. An analysis scheme
defines language-specific text processing options for a text field.
Can be limited to specific analysis schemes by name. By default, shows
all analysis schemes and includes any pending changes to the
configuration. Set the Deployed option to true to show the active
configuration and exclude pending changes. For more information, see
Configuring Analysis Schemes in the Amazon CloudSearch Developer
Guide.
310 |
# File 'sig/client.rbs', line 310
def describe_analysis_schemes: (
|
#describe_availability_options(params = {}) ⇒ Types::DescribeAvailabilityOptionsResponse
Gets the availability options configured for a domain. By default,
shows the configuration with any pending changes. Set the Deployed
option to true to show the active configuration and exclude pending
changes. For more information, see Configuring Availability
Options in the Amazon CloudSearch Developer Guide.
322 |
# File 'sig/client.rbs', line 322
def describe_availability_options: (
|
#describe_domain_endpoint_options(params = {}) ⇒ Types::DescribeDomainEndpointOptionsResponse
Returns the domain's endpoint options, specifically whether all requests to the domain must arrive over HTTPS. For more information, see Configuring Domain Endpoint Options in the Amazon CloudSearch Developer Guide.
333 |
# File 'sig/client.rbs', line 333
def describe_domain_endpoint_options: (
|
#describe_domains(params = {}) ⇒ Types::DescribeDomainsResponse
Gets information about the search domains owned by this account. Can
be limited to specific domains. Shows all domains by default. To get
the number of searchable documents in a domain, use the console or
submit a matchall request to your domain's search endpoint:
q=matchall&q.parser=structured&size=0. For more information,
see Getting Information about a Search Domain in the Amazon
CloudSearch Developer Guide.
344 |
# File 'sig/client.rbs', line 344
def describe_domains: (
|
#describe_expressions(params = {}) ⇒ Types::DescribeExpressionsResponse
Gets the expressions configured for the search domain. Can be limited
to specific expressions by name. By default, shows all expressions and
includes any pending changes to the configuration. Set the Deployed
option to true to show the active configuration and exclude pending
changes. For more information, see Configuring Expressions in the
Amazon CloudSearch Developer Guide.
354 |
# File 'sig/client.rbs', line 354
def describe_expressions: (
|
#describe_index_fields(params = {}) ⇒ Types::DescribeIndexFieldsResponse
Gets information about the index fields configured for the search
domain. Can be limited to specific fields by name. By default, shows
all fields and includes any pending changes to the configuration. Set
the Deployed option to true to show the active configuration and
exclude pending changes. For more information, see Getting Domain
Information in the Amazon CloudSearch Developer Guide.
366 |
# File 'sig/client.rbs', line 366
def describe_index_fields: (
|
#describe_scaling_parameters(params = {}) ⇒ Types::DescribeScalingParametersResponse
Gets the scaling parameters configured for a domain. A domain's scaling parameters specify the desired search instance type and replication count. For more information, see Configuring Scaling Options in the Amazon CloudSearch Developer Guide.
378 |
# File 'sig/client.rbs', line 378
def describe_scaling_parameters: (
|
#describe_service_access_policies(params = {}) ⇒ Types::DescribeServiceAccessPoliciesResponse
Gets information about the access policies that control access to the
domain's document and search endpoints. By default, shows the
configuration with any pending changes. Set the Deployed option to
true to show the active configuration and exclude pending changes.
For more information, see Configuring Access for a Search Domain
in the Amazon CloudSearch Developer Guide.
388 |
# File 'sig/client.rbs', line 388
def describe_service_access_policies: (
|
#describe_suggesters(params = {}) ⇒ Types::DescribeSuggestersResponse
Gets the suggesters configured for a domain. A suggester enables you
to display possible matches before users finish typing their queries.
Can be limited to specific suggesters by name. By default, shows all
suggesters and includes any pending changes to the configuration. Set
the Deployed option to true to show the active configuration and
exclude pending changes. For more information, see Getting Search
Suggestions in the Amazon CloudSearch Developer Guide.
399 |
# File 'sig/client.rbs', line 399
def describe_suggesters: (
|
#index_documents(params = {}) ⇒ Types::IndexDocumentsResponse
Tells the search domain to start indexing its documents using the
latest indexing options. This operation must be invoked to activate
options whose OptionStatus is RequiresIndexDocuments.
411 |
# File 'sig/client.rbs', line 411
def index_documents: (
|
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Lists all search domains owned by an account.
421 422 |
# File 'sig/client.rbs', line 421
def list_domain_names: () -> _ListDomainNamesResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _ListDomainNamesResponseSuccess
|
#update_availability_options(params = {}) ⇒ Types::UpdateAvailabilityOptionsResponse
Configures the availability options for a domain. Enabling the Multi-AZ option expands an Amazon CloudSearch domain to an additional Availability Zone in the same Region to increase fault tolerance in the event of a service disruption. Changes to the Multi-AZ option can take about half an hour to become active. For more information, see Configuring Availability Options in the Amazon CloudSearch Developer Guide.
429 |
# File 'sig/client.rbs', line 429
def update_availability_options: (
|
#update_domain_endpoint_options(params = {}) ⇒ Types::UpdateDomainEndpointOptionsResponse
Updates the domain's endpoint options, specifically whether all requests to the domain must arrive over HTTPS. For more information, see Configuring Domain Endpoint Options in the Amazon CloudSearch Developer Guide.
440 |
# File 'sig/client.rbs', line 440
def update_domain_endpoint_options: (
|
#update_scaling_parameters(params = {}) ⇒ Types::UpdateScalingParametersResponse
Configures scaling parameters for a domain. A domain's scaling parameters specify the desired search instance type and replication count. Amazon CloudSearch will still automatically scale your domain based on the volume of data and traffic, but not below the desired instance type and replication count. If the Multi-AZ option is enabled, these values control the resources used per Availability Zone. For more information, see Configuring Scaling Options in the Amazon CloudSearch Developer Guide.
454 |
# File 'sig/client.rbs', line 454
def update_scaling_parameters: (
|
#update_service_access_policies(params = {}) ⇒ Types::UpdateServiceAccessPoliciesResponse
Configures the access rules that control access to the domain's document and search endpoints. For more information, see Configuring Access for an Amazon CloudSearch Domain.
469 |
# File 'sig/client.rbs', line 469
def update_service_access_policies: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2006 2007 2008 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 2006 def waiter_names [] end |