Class: Aws::CloudSearch::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudSearch::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloudsearch/client.rb
Overview
An API client for CloudSearch. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::CloudSearch::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#build_suggesters(params = {}) ⇒ Types::BuildSuggestersResponse
Indexes the search suggestions.
-
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a new search domain.
-
#define_analysis_scheme(params = {}) ⇒ Types::DefineAnalysisSchemeResponse
Configures an analysis scheme that can be applied to a ‘text` or `text-array` field to define language-specific text processing options.
-
#define_expression(params = {}) ⇒ Types::DefineExpressionResponse
Configures an ‘Expression` for the search domain.
-
#define_index_field(params = {}) ⇒ Types::DefineIndexFieldResponse
Configures an ‘IndexField` for the search domain.
-
#define_suggester(params = {}) ⇒ Types::DefineSuggesterResponse
Configures a suggester for a domain.
-
#delete_analysis_scheme(params = {}) ⇒ Types::DeleteAnalysisSchemeResponse
Deletes an analysis scheme.
-
#delete_domain(params = {}) ⇒ Types::DeleteDomainResponse
Permanently deletes a search domain and all of its data.
-
#delete_expression(params = {}) ⇒ Types::DeleteExpressionResponse
Removes an ‘Expression` from the search domain.
-
#delete_index_field(params = {}) ⇒ Types::DeleteIndexFieldResponse
Removes an ‘IndexField` from the search domain.
-
#delete_suggester(params = {}) ⇒ Types::DeleteSuggesterResponse
Deletes a suggester.
-
#describe_analysis_schemes(params = {}) ⇒ Types::DescribeAnalysisSchemesResponse
Gets the analysis schemes configured for a domain.
-
#describe_availability_options(params = {}) ⇒ Types::DescribeAvailabilityOptionsResponse
Gets the availability options configured for a domain.
-
#describe_domain_endpoint_options(params = {}) ⇒ Types::DescribeDomainEndpointOptionsResponse
Returns the domain’s endpoint options, specifically whether all requests to the domain must arrive over HTTPS.
-
#describe_domains(params = {}) ⇒ Types::DescribeDomainsResponse
Gets information about the search domains owned by this account.
-
#describe_expressions(params = {}) ⇒ Types::DescribeExpressionsResponse
Gets the expressions configured for the search domain.
-
#describe_index_fields(params = {}) ⇒ Types::DescribeIndexFieldsResponse
Gets information about the index fields configured for the search domain.
-
#describe_scaling_parameters(params = {}) ⇒ Types::DescribeScalingParametersResponse
Gets the scaling parameters configured for a domain.
-
#describe_service_access_policies(params = {}) ⇒ Types::DescribeServiceAccessPoliciesResponse
Gets information about the access policies that control access to the domain’s document and search endpoints.
-
#describe_suggesters(params = {}) ⇒ Types::DescribeSuggestersResponse
Gets the suggesters configured for a domain.
-
#index_documents(params = {}) ⇒ Types::IndexDocumentsResponse
Tells the search domain to start indexing its documents using the latest indexing options.
-
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Lists all search domains owned by an account.
-
#update_availability_options(params = {}) ⇒ Types::UpdateAvailabilityOptionsResponse
Configures the availability options for a domain.
-
#update_domain_endpoint_options(params = {}) ⇒ Types::UpdateDomainEndpointOptionsResponse
Updates the domain’s endpoint options, specifically whether all requests to the domain must arrive over HTTPS.
-
#update_scaling_parameters(params = {}) ⇒ Types::UpdateScalingParametersResponse
Configures scaling parameters for a domain.
-
#update_service_access_policies(params = {}) ⇒ Types::UpdateServiceAccessPoliciesResponse
Configures the access rules that control access to the domain’s document and search endpoints.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2013 2014 2015 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 2013 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2016 2017 2018 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 2016 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1986 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CloudSearch') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cloudsearch' context[:gem_version] = '1.89.0' Seahorse::Client::Request.new(handlers, context) end |
#build_suggesters(params = {}) ⇒ Types::BuildSuggestersResponse
Indexes the search suggestions. For more information, see [Configuring Suggesters] in the *Amazon CloudSearch Developer Guide*.
507 508 509 510 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 507 def build_suggesters(params = {}, = {}) req = build_request(:build_suggesters, params) req.send_request() end |
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a new search domain. For more information, see [Creating a Search Domain] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/creating-domains.html
554 555 556 557 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 554 def create_domain(params = {}, = {}) req = build_request(:create_domain, params) req.send_request() end |
#define_analysis_scheme(params = {}) ⇒ Types::DefineAnalysisSchemeResponse
Configures an analysis scheme that can be applied to a ‘text` or `text-array` field to define language-specific text processing options. For more information, see [Configuring Analysis Schemes] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-analysis-schemes.html
619 620 621 622 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 619 def define_analysis_scheme(params = {}, = {}) req = build_request(:define_analysis_scheme, params) req.send_request() end |
#define_expression(params = {}) ⇒ Types::DefineExpressionResponse
Configures an ‘Expression` for the search domain. Used to create new expressions and modify existing ones. If the expression exists, the new configuration replaces the old one. For more information, see
- Configuring Expressions][1
-
in the *Amazon CloudSearch Developer
Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-expressions.html
671 672 673 674 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 671 def define_expression(params = {}, = {}) req = build_request(:define_expression, params) req.send_request() end |
#define_index_field(params = {}) ⇒ Types::DefineIndexFieldResponse
Configures an ‘IndexField` for the search domain. Used to create new fields and modify existing ones. You must specify the name of the domain you are configuring and an index field configuration. The index field configuration specifies a unique name, the index field type, and the options you want to configure for the field. The options you can specify depend on the `IndexFieldType`. If the field exists, the new configuration replaces the old one. For more information, see
- Configuring Index Fields][1
-
in the *Amazon CloudSearch Developer
Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-index-fields.html
869 870 871 872 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 869 def define_index_field(params = {}, = {}) req = build_request(:define_index_field, params) req.send_request() end |
#define_suggester(params = {}) ⇒ Types::DefineSuggesterResponse
Configures a suggester for a domain. A suggester enables you to display possible matches before users finish typing their queries. When you configure a suggester, you must specify the name of the text field you want to search for possible matches and a unique name for the suggester. For more information, see [Getting Search Suggestions] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-suggestions.html
929 930 931 932 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 929 def define_suggester(params = {}, = {}) req = build_request(:define_suggester, params) req.send_request() end |
#delete_analysis_scheme(params = {}) ⇒ Types::DeleteAnalysisSchemeResponse
Deletes an analysis scheme. For more information, see [Configuring Analysis Schemes] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-analysis-schemes.html
978 979 980 981 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 978 def delete_analysis_scheme(params = {}, = {}) req = build_request(:delete_analysis_scheme, params) req.send_request() end |
#delete_domain(params = {}) ⇒ Types::DeleteDomainResponse
Permanently deletes a search domain and all of its data. Once a domain has been deleted, it cannot be recovered. For more information, see
- Deleting a Search Domain][1
-
in the *Amazon CloudSearch Developer
Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/deleting-domains.html
1024 1025 1026 1027 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1024 def delete_domain(params = {}, = {}) req = build_request(:delete_domain, params) req.send_request() end |
#delete_expression(params = {}) ⇒ Types::DeleteExpressionResponse
Removes an ‘Expression` from the search domain. For more information, see [Configuring Expressions] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-expressions.html
1069 1070 1071 1072 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1069 def delete_expression(params = {}, = {}) req = build_request(:delete_expression, params) req.send_request() end |
#delete_index_field(params = {}) ⇒ Types::DeleteIndexFieldResponse
Removes an ‘IndexField` from the search domain. For more information, see [Configuring Index Fields] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-index-fields.html
1176 1177 1178 1179 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1176 def delete_index_field(params = {}, = {}) req = build_request(:delete_index_field, params) req.send_request() end |
#delete_suggester(params = {}) ⇒ Types::DeleteSuggesterResponse
Deletes a suggester. For more information, see [Getting Search Suggestions] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-suggestions.html
1222 1223 1224 1225 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1222 def delete_suggester(params = {}, = {}) req = build_request(:delete_suggester, params) req.send_request() end |
#describe_analysis_schemes(params = {}) ⇒ Types::DescribeAnalysisSchemesResponse
Gets the analysis schemes configured for a domain. An analysis scheme defines language-specific text processing options for a ‘text` field. Can be limited to specific analysis schemes by name. By default, shows all analysis schemes and includes any pending changes to the configuration. Set the `Deployed` option to `true` to show the active configuration and exclude pending changes. For more information, see
- Configuring Analysis Schemes][1
-
in the *Amazon CloudSearch Developer
Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-analysis-schemes.html
1280 1281 1282 1283 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1280 def describe_analysis_schemes(params = {}, = {}) req = build_request(:describe_analysis_schemes, params) req.send_request() end |
#describe_availability_options(params = {}) ⇒ Types::DescribeAvailabilityOptionsResponse
Gets the availability options configured for a domain. By default, shows the configuration with any pending changes. Set the ‘Deployed` option to `true` to show the active configuration and exclude pending changes. For more information, see [Configuring Availability Options] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-availability-options.html
1324 1325 1326 1327 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1324 def (params = {}, = {}) req = build_request(:describe_availability_options, params) req.send_request() end |
#describe_domain_endpoint_options(params = {}) ⇒ Types::DescribeDomainEndpointOptionsResponse
Returns the domain’s endpoint options, specifically whether all requests to the domain must arrive over HTTPS. For more information, see [Configuring Domain Endpoint Options] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-domain-endpoint-options.html
1369 1370 1371 1372 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1369 def (params = {}, = {}) req = build_request(:describe_domain_endpoint_options, params) req.send_request() end |
#describe_domains(params = {}) ⇒ Types::DescribeDomainsResponse
Gets information about the search domains owned by this account. Can be limited to specific domains. Shows all domains by default. To get the number of searchable documents in a domain, use the console or submit a ‘matchall` request to your domain’s search endpoint: ‘q=matchall&q.parser=structured&size=0`. For more information, see [Getting Information about a Search Domain] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-domain-info.html
1419 1420 1421 1422 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1419 def describe_domains(params = {}, = {}) req = build_request(:describe_domains, params) req.send_request() end |
#describe_expressions(params = {}) ⇒ Types::DescribeExpressionsResponse
Gets the expressions configured for the search domain. Can be limited to specific expressions by name. By default, shows all expressions and includes any pending changes to the configuration. Set the ‘Deployed` option to `true` to show the active configuration and exclude pending changes. For more information, see [Configuring Expressions] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-expressions.html
1471 1472 1473 1474 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1471 def describe_expressions(params = {}, = {}) req = build_request(:describe_expressions, params) req.send_request() end |
#describe_index_fields(params = {}) ⇒ Types::DescribeIndexFieldsResponse
Gets information about the index fields configured for the search domain. Can be limited to specific fields by name. By default, shows all fields and includes any pending changes to the configuration. Set the ‘Deployed` option to `true` to show the active configuration and exclude pending changes. For more information, see [Getting Domain Information] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-domain-info.html
1584 1585 1586 1587 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1584 def describe_index_fields(params = {}, = {}) req = build_request(:describe_index_fields, params) req.send_request() end |
#describe_scaling_parameters(params = {}) ⇒ Types::DescribeScalingParametersResponse
Gets the scaling parameters configured for a domain. A domain’s scaling parameters specify the desired search instance type and replication count. For more information, see [Configuring Scaling Options] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-scaling-options.html
1627 1628 1629 1630 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1627 def describe_scaling_parameters(params = {}, = {}) req = build_request(:describe_scaling_parameters, params) req.send_request() end |
#describe_service_access_policies(params = {}) ⇒ Types::DescribeServiceAccessPoliciesResponse
Gets information about the access policies that control access to the domain’s document and search endpoints. By default, shows the configuration with any pending changes. Set the ‘Deployed` option to `true` to show the active configuration and exclude pending changes. For more information, see [Configuring Access for a Search Domain] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-access.html
1672 1673 1674 1675 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1672 def describe_service_access_policies(params = {}, = {}) req = build_request(:describe_service_access_policies, params) req.send_request() end |
#describe_suggesters(params = {}) ⇒ Types::DescribeSuggestersResponse
Gets the suggesters configured for a domain. A suggester enables you to display possible matches before users finish typing their queries. Can be limited to specific suggesters by name. By default, shows all suggesters and includes any pending changes to the configuration. Set the ‘Deployed` option to `true` to show the active configuration and exclude pending changes. For more information, see [Getting Search Suggestions] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/getting-suggestions.html
1726 1727 1728 1729 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1726 def describe_suggesters(params = {}, = {}) req = build_request(:describe_suggesters, params) req.send_request() end |
#index_documents(params = {}) ⇒ Types::IndexDocumentsResponse
Tells the search domain to start indexing its documents using the latest indexing options. This operation must be invoked to activate options whose OptionStatus is ‘RequiresIndexDocuments`.
1758 1759 1760 1761 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1758 def index_documents(params = {}, = {}) req = build_request(:index_documents, params) req.send_request() end |
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Lists all search domains owned by an account.
1776 1777 1778 1779 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1776 def list_domain_names(params = {}, = {}) req = build_request(:list_domain_names, params) req.send_request() end |
#update_availability_options(params = {}) ⇒ Types::UpdateAvailabilityOptionsResponse
Configures the availability options for a domain. Enabling the Multi-AZ option expands an Amazon CloudSearch domain to an additional Availability Zone in the same Region to increase fault tolerance in the event of a service disruption. Changes to the Multi-AZ option can take about half an hour to become active. For more information, see
- Configuring Availability Options][1
-
in the *Amazon CloudSearch
Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-availability-options.html
1827 1828 1829 1830 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1827 def (params = {}, = {}) req = build_request(:update_availability_options, params) req.send_request() end |
#update_domain_endpoint_options(params = {}) ⇒ Types::UpdateDomainEndpointOptionsResponse
Updates the domain’s endpoint options, specifically whether all requests to the domain must arrive over HTTPS. For more information, see [Configuring Domain Endpoint Options] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-domain-endpoint-options.html
1876 1877 1878 1879 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1876 def (params = {}, = {}) req = build_request(:update_domain_endpoint_options, params) req.send_request() end |
#update_scaling_parameters(params = {}) ⇒ Types::UpdateScalingParametersResponse
Configures scaling parameters for a domain. A domain’s scaling parameters specify the desired search instance type and replication count. Amazon CloudSearch will still automatically scale your domain based on the volume of data and traffic, but not below the desired instance type and replication count. If the Multi-AZ option is enabled, these values control the resources used per Availability Zone. For more information, see [Configuring Scaling Options] in the *Amazon CloudSearch Developer Guide*.
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-scaling-options.html
1932 1933 1934 1935 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1932 def update_scaling_parameters(params = {}, = {}) req = build_request(:update_scaling_parameters, params) req.send_request() end |
#update_service_access_policies(params = {}) ⇒ Types::UpdateServiceAccessPoliciesResponse
Configures the access rules that control access to the domain’s document and search endpoints. For more information, see [ Configuring Access for an Amazon CloudSearch Domain].
[1]: docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-access.html
1977 1978 1979 1980 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 1977 def update_service_access_policies(params = {}, = {}) req = build_request(:update_service_access_policies, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2006 2007 2008 |
# File 'lib/aws-sdk-cloudsearch/client.rb', line 2006 def waiter_names [] end |